# azure-log-analytics-data-collector Python Client libraries

[Azure Log Analytics Data Collector API](https://docs.microsoft.com/en-us/azure/azure-monitor/platform/data-collector-api) Client libraries for Python. The probject was originally started in a repository, [azure-log-analytics-data-collector](https://github.com/yokawasa/azure-log-analytics-data-collector), then moved here as a dedicated repository for Python client.

## Installation
```
pip install azure-log-analytics-data-collector-api

# Or Upgrade
pip install azure-log-analytics-data-collector-api --upgrade
```

## Sample Code (Python Client)
* [Sample Code](test/testclient.py)

## Change log

* [Changelog](ChangeLog.md)

## Links

* https://pypi.python.org/pypi/azure-log-analytics-data-collector-api
* [Azure Log Analytics Data Collecotr API](https://docs.microsoft.com/en-us/azure/log-analytics/log-analytics-data-collector-api)

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/yokawasa/azure-log-analytics-data-collector-python.
